/*
Module : HLINKCTRL.CPP
Purpose: Implementation for a MFC class for a static text control class with hyperlink support
Created: PJN / HLINK/1 / 16-06-1997
History: PJN /         / 24-06-1997, hyperlinks are now coloured ala IE
         PJN /         / 15-07-1997, Now supports ShrinkToFit

Copyright (c) 1997 by PJ Naughter.  
All rights reserved.

*/

/////////////////////////////////  Includes  //////////////////////////////////
#include "stdafx.h"
#include "resource.h"
#include "hlinkctrl.h"



/////////////////////////////////  Macros /////////////////////////////////////

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif


///////////////////////////////// Implementation //////////////////////////////

BEGIN_MESSAGE_MAP(CHLinkCtrl, CEdit)
	//{{AFX_MSG_MAP(CHLinkCtrl)
  ON_WM_SETCURSOR()
  ON_WM_LBUTTONDOWN()
	ON_WM_CTLCOLOR_REFLECT()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()


CHLinkCtrl::CHLinkCtrl()
{
	m_Color = RGB(0, 0, 238);
	m_VisitedColor = RGB(85, 26, 139);
	m_bVisited = FALSE;
	m_bShrinkToFit = TRUE;
}


CHLinkCtrl::~CHLinkCtrl()
{
}

void CHLinkCtrl::ShrinkToFitEditBox()
{
	CWnd *pParent = GetParent();
	if (!pParent)
		return;

	CClientDC dc(this);
	dc.SetMapMode(MM_TEXT);
	CSize TextSize = dc.GetTextExtent(m_sLinkDescription);
	dc.LPtoDP(&TextSize);

	CRect ControlRect;
	GetWindowRect(&ControlRect);
	pParent->ScreenToClient(&ControlRect);

	if (ControlRect.Size().cx != TextSize.cx)
	{
    // we need to Shink the edit box
		// keep everything the same except the width.  Set that to the width of text 
		MoveWindow(ControlRect.left, ControlRect.top, TextSize.cx, ControlRect.Height());
	}

}

void CHLinkCtrl::SetHyperLink(const CString& sActualLink)
{
	SetHyperLink(sActualLink, sActualLink, TRUE);
}


void CHLinkCtrl::SetHyperLink(const CString& sActualLink, const CString& sLinkDescription, BOOL bShrinkToFit)
{
  m_bShrinkToFit = bShrinkToFit;
	SetActualHyperLink(sActualLink);
	SetHyperLinkDescription(sLinkDescription);
}


void CHLinkCtrl::SetActualHyperLink(const CString& sActualLink)
{
	m_sActualLink = sActualLink;
}


void CHLinkCtrl::SetHyperLinkDescription(const CString& sLinkDescription)
{
	ASSERT(sLinkDescription.GetLength() > 0);

	//Control should be created read only
	ASSERT(GetStyle() & ES_READONLY);

	//Control should not be in the tab order
	ASSERT((GetStyle() & WS_TABSTOP) == 0);

	//store away the paramaters
	m_sLinkDescription = sLinkDescription;

	//set the text on this control
	SetWindowText(sLinkDescription);

	if (m_bShrinkToFit)
		ShrinkToFitEditBox();
	
	//Load up the hyperlink cursor
	m_hLinkCursor = AfxGetApp()->LoadCursor(IDC_HLINK);
}


BOOL CHLinkCtrl::OnSetCursor(CWnd* /*pWnd*/, UINT /*nHitTest*/, UINT /*message*/) 
{
	::SetCursor(m_hLinkCursor);

	return TRUE;
}


void CHLinkCtrl::OnLButtonDown(UINT /*nFlags*/, CPoint /*point*/) 
{
	m_bVisited = TRUE;
	ShellExecute(AfxGetMainWnd()->GetSafeHwnd(), _T("open"), m_sActualLink, NULL, NULL, SW_SHOW);
}


HBRUSH CHLinkCtrl::CtlColor(CDC* pDC, UINT nCtlColor) 
{
	if (m_bVisited)
		pDC->SetTextColor(m_VisitedColor);
	else
		pDC->SetTextColor(m_Color);

	// transparent text.
	pDC->SetBkMode(TRANSPARENT);
	return (HBRUSH)GetStockObject(NULL_BRUSH);
}


void CHLinkCtrl::SetLinkColor(const COLORREF& color) 
{ 
	m_Color = color; 
	UpdateWindow(); 
}


void CHLinkCtrl::SetVisitedLinkColor(const COLORREF& color) 
{ 
	m_VisitedColor = color; 
	UpdateWindow(); 
}


void CHLinkCtrl::SetVisited(BOOL bVisited) 
{ 
	m_bVisited = bVisited; 
	UpdateWindow(); 
}



